==> jc-1.4.0.tar.gz: gnu/java/nio/OutputStreamChannel.h <==
// public final class gnu.java.nio.OutputStreamChannel

// class file dependencies
// @dep_class 9fb67eb498f272d3 gnu_java_nio_OutputStreamChannel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_OutputStreamChannel_H_
#define _JC_gnu_java_nio_OutputStreamChannel_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_gnu_java_nio_OutputStreamChannel$sub_refs	_jc_gnu_java_nio_OutputStreamChannel$sub_refs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs	_jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$refs	_jc_gnu_java_nio_OutputStreamChannel$refs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$nonrefs	_jc_gnu_java_nio_OutputStreamChannel$nonrefs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$object	_jc_gnu_java_nio_OutputStreamChannel$object;

typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vmethods	_jc_gnu_java_nio_OutputStreamChannel$vmethods;
typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vtable	_jc_gnu_java_nio_OutputStreamChannel$vtable;
typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vtype	_jc_gnu_java_nio_OutputStreamChannel$vtype;

// Constructors
extern void _jc_gnu_java_nio_OutputStreamChannel$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_nio_OutputStreamChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
extern jboolean _jc_gnu_java_nio_OutputStreamChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
extern void _jc_gnu_java_nio_OutputStreamChannel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
extern jint _jc_gnu_java_nio_OutputStreamChannel$method$write$5ecbda8c634879d7(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$isOpen$ac3c28a31bf5ea5b;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$write$5ecbda8c634879d7;

// Virtual methods structure
struct _jc_gnu_java_nio_OutputStreamChannel$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *);
	jint	(*write$5ecbda8c634879d7)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *);
};

// Vtable
struct _jc_gnu_java_nio_OutputStreamChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_OutputStreamChannel$vmethods	gnu_java_nio_OutputStreamChannel;
};

// Vtype
struct _jc_gnu_java_nio_OutputStreamChannel$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_OutputStreamChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_OutputStreamChannel$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_OutputStreamChannel$refs {
    _jc_gnu_java_nio_OutputStreamChannel$sub_refs	gnu_java_nio_OutputStreamChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_OutputStreamChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs	gnu_java_nio_OutputStreamChannel;
};

// Object instance structure
struct _jc_gnu_java_nio_OutputStreamChannel$object {
	_jc_gnu_java_nio_OutputStreamChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_OutputStreamChannel$vtype	*vtype;
	_jc_gnu_java_nio_OutputStreamChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_OutputStreamChannel$vtype _jc_gnu_java_nio_OutputStreamChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_OutputStreamChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_OutputStreamChannel$class_object;

#endif	/* _JC_gnu_java_nio_OutputStreamChannel_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/OutputStreamChannel.h <==
// public final class gnu.java.nio.OutputStreamChannel

// class file dependencies
// @dep_class 9fb67eb498f272d3 gnu_java_nio_OutputStreamChannel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_nio_OutputStreamChannel_H_
#define _JC_gnu_java_nio_OutputStreamChannel_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;

// Typedefs
typedef struct _jc_gnu_java_nio_OutputStreamChannel$sub_refs	_jc_gnu_java_nio_OutputStreamChannel$sub_refs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs	_jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$refs	_jc_gnu_java_nio_OutputStreamChannel$refs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$nonrefs	_jc_gnu_java_nio_OutputStreamChannel$nonrefs;
typedef struct _jc_gnu_java_nio_OutputStreamChannel$object	_jc_gnu_java_nio_OutputStreamChannel$object;

typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vmethods	_jc_gnu_java_nio_OutputStreamChannel$vmethods;
typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vtable	_jc_gnu_java_nio_OutputStreamChannel$vtable;
typedef const struct _jc_gnu_java_nio_OutputStreamChannel$vtype	_jc_gnu_java_nio_OutputStreamChannel$vtype;

// Constructors
extern void _jc_gnu_java_nio_OutputStreamChannel$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_nio_OutputStreamChannel$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_nio_OutputStreamChannel$method$isOpen$ac3c28a31bf5ea5b(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_OutputStreamChannel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_OutputStreamChannel$method$write$5ecbda8c634879d7(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$isOpen$ac3c28a31bf5ea5b;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_nio_OutputStreamChannel$method_info$write$5ecbda8c634879d7;

// Virtual methods structure
struct _jc_gnu_java_nio_OutputStreamChannel$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
	jboolean	(*isOpen$ac3c28a31bf5ea5b)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *) _JC_JCNI_ATTR;
	jint	(*write$5ecbda8c634879d7)(_jc_env *, struct _jc_gnu_java_nio_OutputStreamChannel$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_OutputStreamChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_nio_OutputStreamChannel$vmethods	gnu_java_nio_OutputStreamChannel;
};

// Vtype
struct _jc_gnu_java_nio_OutputStreamChannel$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_OutputStreamChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_OutputStreamChannel$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_OutputStreamChannel$refs {
    _jc_gnu_java_nio_OutputStreamChannel$sub_refs	gnu_java_nio_OutputStreamChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_OutputStreamChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_nio_OutputStreamChannel$sub_nonrefs	gnu_java_nio_OutputStreamChannel;
};

// Object instance structure
struct _jc_gnu_java_nio_OutputStreamChannel$object {
	_jc_gnu_java_nio_OutputStreamChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_OutputStreamChannel$vtype	*vtype;
	_jc_gnu_java_nio_OutputStreamChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_OutputStreamChannel$vtype _jc_gnu_java_nio_OutputStreamChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_OutputStreamChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_OutputStreamChannel$class_object;

#endif	/* _JC_gnu_java_nio_OutputStreamChannel_H_ */
